@@ -4,10 +4,6 @@
  * NO lo compile como parte de su aplicación.
  */
 
-gchar *s = N_("Time zone");
-gchar *s = N_("Time servers");
-gchar *s = N_("Select the servers you wish to use for time synchronization.");
-gchar *s = N_("*");
 gchar *s = N_("Select a time zone by clicking on \n"
               "one of the dots on the map.");
 gchar *s = N_("Selection:");
@@ -16,14 +12,14 @@ gchar *s = N_("Select the servers you wish to use for time synchronization.");
 gchar *s = N_("*");
 gchar *s = N_("window1");
 gchar *s = N_("Please select the current date and time. You can also specify a time zone and a time server.");
-gchar *s = N_("<span weight=\"bold\">Time configuration</span>");
+gchar *s = N_("<span weight=\"bold\">Time Configuration</span>");
 gchar *s = N_("_Time:");
-gchar *s = N_("Time _zone:");
+gchar *s = N_("Time zone:");
 gchar *s = N_(":");
 gchar *s = N_(":");
 gchar *s = N_("(unconfigured)");
-gchar *s = N_("Select time _zone...");
+gchar *s = N_("_Select Time Zone...");
 gchar *s = N_("_Date:");
-gchar *s = N_("<span weight=\"bold\">Time server</span>");
-gchar *s = N_("Select _servers...");
-gchar *s = N_("Synchronize _clock with internet servers");
+gchar *s = N_("<span weight=\"bold\">Time Server</span>");
+gchar *s = N_("Se_lect Servers...");
+gchar *s = N_("S_ynchronize clock with internet servers");
