@@ -31,10 +31,18 @@ void	  on_boot_table_cursor_changed	(GtkTreeSelection*, gpointer);
 void      on_boot_delete_clicked    (GtkButton *button, gpointer data);
 void      on_boot_settings_clicked  (GtkButton *button, gpointer data);
 void      on_boot_default_clicked   (GtkButton *button, gpointer data);
-void      on_main_dialog_update_complexity (XstDialog *main_dialog, gpointer data);
+void      on_main_dialog_update_complexity (GstDialog *main_dialog, gpointer data);
 
 void      callbacks_actions_set_sensitive      (gboolean state);
-gboolean  callbacks_conf_read_failed_hook (XstTool *tool, XstReportLine *rline, gpointer data);
+gboolean  callbacks_conf_read_failed_hook (GstTool *tool, GstReportLine *rline, gpointer data);
+
+void on_popup_add_activate (gpointer, guint, GtkWidget*);
+void on_popup_settings_activate (gpointer, guint, GtkWidget*);
+void on_popup_delete_activate (gpointer, guint, GtkWidget*);
+gboolean on_boot_table_button_press (GtkTreeView*, GdkEventButton*, gpointer);
+
+void on_boot_add_clicked (GtkButton*, gpointer);
+void on_boot_settings_clicked (GtkButton*, gpointer);
 
 #endif /* CALLBACKS_H */
 
