@@ -28,13 +28,19 @@
 #include <gnome.h>
 #include <gtk/gtk.h>
 
-#include "xst.h"
+#include "gst.h"
 
+#include "table.h"
 #include "users-table.h"
 #include "user_group.h"
 #include "callbacks.h"
 #include "user-group-xml.h"
 
+extern GstTool *tool;
+
+GtkWidget *users_table;
+GArray *users_array;
+
 TableConfig users_table_config [] = {
 	/*Column name,          Adv_state_show,	Basic_state_show*/
 	{ N_("User"),		TRUE,		TRUE},
@@ -46,11 +52,6 @@ TableConfig users_table_config [] = {
 	{NULL}
 };
 
-extern XstTool *tool;
-
-GtkWidget *users_table;
-GArray *users_array;
-
 static void
 add_user_columns (GtkTreeView *treeview)
 {
@@ -65,7 +66,7 @@ add_user_columns (GtkTreeView *treeview)
 	{	
 		renderer = gtk_cell_renderer_text_new ();
 	
-		column = gtk_tree_view_column_new_with_attributes (i->name,
+		column = gtk_tree_view_column_new_with_attributes (_(i->name),
 	                                                           renderer,
 	                                                           "text",
 	                                                           j,
@@ -94,51 +95,42 @@ create_users_model (void)
 	return GTK_TREE_MODEL (model);
 }
 
-static GtkWidget*
+
+
+void
 create_users_table (void)
 {
 	GtkTreeSelection *selection;
 	GtkTreeModel *model;
+	GtkItemFactory *item_factory;
 	
 	model = create_users_model ();
 	
-	users_table = gtk_tree_view_new_with_model (model);
+	users_table = gst_dialog_get_widget (tool->main_dialog, "users_table");
+	gtk_tree_view_set_model (GTK_TREE_VIEW (users_table), model);
 	
 	g_object_unref (model);
 	
-        gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (users_table), TRUE);
-
 	add_user_columns (GTK_TREE_VIEW (users_table));
 	
 	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (users_table));
 	gtk_tree_selection_set_mode (selection, GTK_SELECTION_MULTIPLE);
 
+	item_factory = popup_item_factory_create (users_table);
+
 	g_signal_connect (G_OBJECT (selection), "changed",
-			  G_CALLBACK (on_user_table_clicked),
-			  NULL);
-	
-	return users_table;
-}
-
-void 
-construct_users_table (void)
-{
-	GtkWidget *sw;
-	GtkWidget *list;
-
-	sw = xst_dialog_get_widget (tool->main_dialog, "users_table");
-
-	list = create_users_table ();
-
-	gtk_widget_show_all (list);
-	gtk_container_add (GTK_CONTAINER (sw), list);
+			  G_CALLBACK (on_table_clicked),
+			  (gpointer) users_table);
+	g_signal_connect (G_OBJECT (users_table), "button_press_event",
+			  G_CALLBACK (on_table_button_press),
+			  (gpointer) item_factory);
 }
 
 static char*
 users_table_value (xmlNodePtr node, gchar *key)
 {
         g_return_val_if_fail (node != NULL, NULL);
-        return xst_xml_get_child_content (node, key);
+        return gst_xml_get_child_content (node, key);
 }
 
 static UserTreeItem*
@@ -160,7 +152,7 @@ void
 populate_users_table (void)
 {
 	GtkTreeModel *model = gtk_tree_view_get_model (GTK_TREE_VIEW (users_table));
-	xmlNodePtr root = get_user_root_node ();
+	xmlNodePtr root = get_root_node (NODE_USER);
 	GtkTreeIter iter;
 	xmlNodePtr user;
 	
@@ -169,7 +161,7 @@ populate_users_table (void)
 	
 	users_array = g_array_new (FALSE, FALSE, sizeof (xmlNodePtr));
 	
-	for (user = xst_xml_element_find_first (root, "user"); user != NULL; user = xst_xml_element_find_next (user, "user"))
+	for (user = gst_xml_element_find_first (root, "user"); user != NULL; user = gst_xml_element_find_next (user, "user"))
 	{
 		if (check_node_visibility (user))
 		{
@@ -192,7 +184,7 @@ populate_users_table (void)
 }
 
 void
-update_users_table_complexity (XstDialogComplexity complexity)
+update_users_table_complexity (GstDialogComplexity complexity)
 {
 	GtkTreeView *u_table = GTK_TREE_VIEW (users_table);
 	GtkTreeViewColumn *column;
@@ -200,7 +192,7 @@ update_users_table_complexity (XstDialogComplexity complexity)
 	guint j;
 	
 	switch (complexity) {
-	case XST_DIALOG_BASIC:
+	case GST_DIALOG_BASIC:
 		for (i = users_table_config, j=0;
 		     i->name != NULL;
 		     i++, j++)
@@ -209,7 +201,7 @@ update_users_table_complexity (XstDialogComplexity complexity)
 			gtk_tree_view_column_set_visible (column, i->basic_state_showable);
 		}
 		break;
-	case XST_DIALOG_ADVANCED:
+	case GST_DIALOG_ADVANCED:
 		for (i = users_table_config, j=0;
 		     i->name != NULL;
 		     i++, j++)
